@@ -1,4 +1,4 @@
-from ._job import Job
+from ._job import Job, JobStatus
 from ._locations import Locations
 from ._system import AbstractSystem
 
@@ -6,4 +6,5 @@ __all__ = [
     'Locations',
     'AbstractSystem',
     'Job',
+    'JobStatus',
 ]
