@@ -1,6 +1,5 @@
 from ._basemodel import BaseModel
-from ._dimensions import (IDSOperation, IDSOperationDim, JettoOperation,
-                          OperationDim)
+from ._dimensions import IDSOperation, IDSOperationDim, JettoOperation, OperationDim
 from ._imas import ImasBaseModel
 from ._jetto import JettoField, JettoVar, JsetField, NamelistField
 from ._ranges import ARange, LinSpace
